import React, { Component } from 'react';
import ReactDOM from 'react-dom';
import ImageButton from './ImageButton.jsx';

class Sidebar extends Component {
  constructor(props) {
    super(props);

    this.state = {
      top: 0,
    };

    this.getSelectedBlockElement = this.getSelectedBlockElement.bind(this);
    this.setBarPosition = this.setBarPosition.bind(this);
  }

  componentDidUpdate() {
    this.setBarPosition();
  }

  getSelectedBlockElement() {
    // Finds the block parent of the current selection
    // https://github.com/facebook/draft-js/issues/45
    const selection = window.getSelection();
    if (selection.rangeCount === 0) {
      return null;
    }
    var node = selection.getRangeAt(0).startContainer;

    do {
      if (node.getAttribute && node.getAttribute('data-block') == 'true') {
        return node;
      }
      node = node.parentNode;
    } while (node !== null);
  }

  setBarPosition() {
    const container = ReactDOM.findDOMNode(this.refs.container);

    const element = this.getSelectedBlockElement();

    if (!element) {
      return;
    }

    const top = Math.floor(
      element.getBoundingClientRect().top - 4 -
      (container.getBoundingClientRect().top -
      document.documentElement.clientTop));

    if (this.state.top !== top) {
      this.setState({
        top
      });
    }
  }

  render() {
    const { top } = this.state;
    const { onChange, editorState, filePickerKey } = this.props;

    return (
      <div ref="container" style={{ position: 'absolute', height: '100%' }}>
        <div style={{position: 'relative', top: `${top}px` }}>
          <ImageButton
            editorState={editorState}
            onChange={onChange}
            filePickerKey={filePickerKey}
          />
        </div>
      </div>
    )
  }
}

export default Sidebar;